@@ -8,7 +8,10 @@ import time
 
 from django.forms import model_to_dict
 from django.utils import timezone
-
+from pathlib import Path
+from main.settings import BASE_DIR
+from ..utils.j_config import JConfig
+from ..utils.j_dict import JDict
 from xj_finance.services.finance_service import FinanceService
 from xj_finance.services.finance_transact_service import FinanceTransactService
 from xj_enroll.service.enroll_services import EnrollServices
@@ -18,6 +21,13 @@ from xj_payment.models import PaymentPayment
 from xj_user.services.user_sso_serve_service import UserSsoServeService
 from ..services.payment_wechat_service import PaymentWechatService
 
+module_root = str(Path(__file__).resolve().parent)
+# 配置之对象
+main_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_payment"))
+module_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_payment"))
+
+sub_appid = main_config_dict.wechat_merchant_app_id or module_config_dict.wechat_merchant_app_id or ""
+
 
 class PaymentService:
     # 支付总接口
@@ -38,7 +48,7 @@ class PaymentService:
             data['user_id'] = enroll_data['user_id']
             data['total_fee'] = float(enroll_data['unpaid_amount']) * 100  # 元转分
         # 单点登录信息
-        sso_data, err = UserSsoServeService.user_sso_to_user(data['user_id'])
+        sso_data, err = UserSsoServeService.user_sso_to_user(data['user_id'], sub_appid)
         if err:
             return "单点登录记录不存在"
         sso_data = model_to_dict(sso_data)
