@@ -1,25 +1,23 @@
 import json
 import logging
 import os
-import requests
-import time
-from django.db import transaction
-from django.forms import model_to_dict
-from django.http import JsonResponse
-from lxml import etree as et
 from pathlib import Path
 from random import sample
 from string import ascii_letters, digits
+import time
 
-from rest_framework import request
+from django.db import transaction
+from django.forms import model_to_dict
+from lxml import etree as et
+import requests
 
+from main.settings import BASE_DIR
+from xj_enroll.service.enroll_services import EnrollServices
 from xj_finance.services.finance_service import FinanceService
 from xj_finance.services.finance_transact_service import FinanceTransactService
 from xj_thread.services.thread_item_service import ThreadItemService
 from xj_user.services.user_service import UserService
-from xj_enroll.service.enroll_services import EnrollServices
 from ..models import PaymentPayment
-from main.settings import BASE_DIR
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
 from ..utils.wechat_utils import my_ali_pay, my_ali_pay_v3, to_text, random_string, applets_red_envelopes
@@ -160,6 +158,8 @@ class PaymentWechatService:
                 package = 'prepay_id=' + prepay_id
                 paysign = wxpay.sign([sub_appid, timestamp, noncestr, package])
                 signtype = 'RSA'
+            else:
+                return {"error": str(result)}
         except Exception as e:
             return {"error": str(e)}
         return {
@@ -187,21 +187,22 @@ class PaymentWechatService:
     # 微信支付 现金红包
     @staticmethod
     def payment_red_envelopes(params):
-        # redpack = applets_red_envelopes()
-        pay = my_ali_pay()
-        redpack = pay.redpack.send(
-            user_id="oj8KR5AR0sV20j96VBcnWulf7bbs",
-            total_amount=1,
-            send_name=merchant_name,
-            act_name="余额提现",
-            wishing="恭喜发财",
-            remark="余额提现红包，请查收",
-        )
+        redpack = applets_red_envelopes()
+        # pay = my_ali_pay()
+        # redpack = pay.redpack.send(
+        #     user_id="oj8KR5AR0sV20j96VBcnWulf7bbs",
+        #     total_amount=1,
+        #     send_name=merchant_name,
+        #     act_name="余额提现",
+        #     wishing="恭喜发财",
+        #     remark="余额提现红包，请查收",
+        # )
         return redpack
 
     # 微信扫码支付
     @staticmethod
     def payment_scan_pay(params):
+        out_trade_no = ''.join(sample(ascii_letters + digits, 8))
         pay = my_ali_pay()
         order = pay.order.create(
             trade_type="NATIVE",  # 交易类型，小程序取值：JSAPI
@@ -210,7 +211,8 @@ class PaymentWechatService:
             notify_url=notify_url,  # 通知地址，异步接收微信支付结果通知的回调地址，通知url必须为外网可访问的url，不能携带参数。
             sub_mch_id=sub_mch_id,
             sub_appid=sub_appid,
-            out_trade_no=params['out_trade_no']
+            # out_trade_no=params['out_trade_no']
+            out_trade_no=out_trade_no
         )
         wxpay_params = pay.jsapi.get_jsapi_params(order['prepay_id'])
         # sign = calculate_sign(body, "POST", self.url, timestamp, nonce_str)
@@ -375,13 +377,15 @@ class PaymentWechatService:
             # 根据订单号查询支付记录是否存在
             payment = PaymentPayment.objects.filter(order_no=int(out_trade_no)).first()
             if not payment:
-                logging.info("payment_callback" + "支付记录不存在")
+                logging.debug(">>>>payment_logic_processing" + "支付记录不存在")
             payment_message = model_to_dict(payment)
             finance_data['account_id'] = payment_message['user_id']
             finance_data['enroll_id'] = payment_message['enroll_id']
             # 根据支付记录用户 查询用户基本信息
             user_set, err = UserService.user_basic_message(payment_message['user_id'])
             user_platform_set, platform_err = UserService.user_basic_message(nickname=sub_appid)
+
+            # 用户报名通知代码块
             if user_set:
                 if payment_message['enroll_id']:
                     # 如果存在报名id 查询报名记录
@@ -393,11 +397,13 @@ class PaymentWechatService:
                             project_name = thread_set['title']
                 summary = "【" + user_set['full_name'] + "】支付 【" + user_platform_set[
                     'full_name'] + "】项目名称【" + project_name + "】款项"
+
             finance_data['summary'] = summary
             # # TODO 拿到订单号后的操作 看自己的业务需求
             # 写入资金模块 （用户支付 (购买支出) ）
             funance_add_data, err_txt = FinanceTransactService.post(finance_data)
             if err_txt:
+                logging.debug(">>>>payment_logic_processing" + "写入资金模块失败（用户支付）")
                 raise Networkerror("Bad hostname")
             # 根据唯一交易id 查询主键id
             finance_data, err = FinanceTransactService.finance_transact_detailed(transaction_id)
@@ -408,7 +414,7 @@ class PaymentWechatService:
                     "transact_id": finance_data['id'],
                     "order_status_id": "24"
                 }
-                # （平台的收入）
+                # （平台收入）
                 platform_revenue_data = {
                     "account_id": finance_data['their_account'],
                     "their_account_id": finance_data['account'],
@@ -422,6 +428,7 @@ class PaymentWechatService:
                 }
                 finance_platform_data_set, finance_platform_err = FinanceTransactService.post(platform_revenue_data)
                 if finance_platform_err:
+                    logging.debug(">>>>payment_logic_processing" + "写入资金模块失败（平台收入）")
                     raise Networkerror("Bad hostname")
                 # 更改支付记录
                 PaymentPayment.objects.filter(order_no=int(out_trade_no)).update(**payment_data)
@@ -429,9 +436,9 @@ class PaymentWechatService:
                 EnrollServices.pay_call_back(out_trade_no)
 
         except Networkerror as t:
-            # print(t)
+            print("支付回调异常：", t)
             transaction.savepoint_rollback(sid)
         except Exception as e:
-            # print(e)
+            print("支付回调异常：", e)
             transaction.savepoint_rollback(sid)
-            logging.info("payment_logic_processing" + e)
+            logging.debug("payment_logic_processing" + e)
